@@ -88,7 +88,7 @@ PyAPI_FUNC(int) PyDict_SetItemString(PyObject *arg0, const char *arg1, PyObject
 PyAPI_FUNC(Py_ssize_t) PyDict_Size(PyObject *arg0);
 PyAPI_FUNC(int) PyDict_Update(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyDict_Values(PyObject *arg0);
-PyAPI_FUNC(void) PyErr_BadArgument(void);
+PyAPI_FUNC(int) PyErr_BadArgument(void);
 PyAPI_FUNC(void) PyErr_BadInternalCall(void);
 PyAPI_FUNC(int) PyErr_CheckSignals(void);
 PyAPI_FUNC(void) PyErr_Clear(void);
@@ -242,6 +242,8 @@ PyAPI_FUNC(PyObject *) PyNumber_Add(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyNumber_And(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(Py_ssize_t) PyNumber_AsSsize_t(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(int) PyNumber_Check(PyObject *arg0);
+PyAPI_FUNC(int) PyNumber_Coerce(PyObject **arg0, PyObject **arg1);
+PyAPI_FUNC(int) PyNumber_CoerceEx(PyObject **arg0, PyObject **arg1);
 PyAPI_FUNC(PyObject *) PyNumber_Divide(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyNumber_Divmod(PyObject *arg0, PyObject *arg1);
 PyAPI_FUNC(PyObject *) PyNumber_Float(PyObject *arg0);
@@ -364,8 +366,8 @@ PyAPI_FUNC(int) PySlice_GetIndices(PySliceObject *arg0, Py_ssize_t arg1, Py_ssiz
 PyAPI_FUNC(int) PySlice_GetIndicesEx(PySliceObject *arg0, Py_ssize_t arg1, Py_ssize_t *arg2, Py_ssize_t *arg3, Py_ssize_t *arg4, Py_ssize_t *arg5);
 PyAPI_FUNC(PyObject *) PySlice_New(PyObject *arg0, PyObject *arg1, PyObject *arg2);
 PyAPI_FUNC(PyObject *) PyStaticMethod_New(PyObject *arg0);
-PyAPI_FUNC(PyObject *) PyString_AsDecodedObject(PyObject *arg0, char *arg1, char *arg2);
-PyAPI_FUNC(PyObject *) PyString_AsEncodedObject(PyObject *arg0, char *arg1, char *arg2);
+PyAPI_FUNC(PyObject *) PyString_AsDecodedObject(PyObject *arg0, const char *arg1, const char *arg2);
+PyAPI_FUNC(PyObject *) PyString_AsEncodedObject(PyObject *arg0, const char *arg1, const char *arg2);
 PyAPI_FUNC(char *) PyString_AsString(PyObject *arg0);
 PyAPI_FUNC(int) PyString_AsStringAndSize(PyObject *arg0, char **arg1, Py_ssize_t *arg2);
 PyAPI_FUNC(int) PyString_Check(PyObject *arg0);
@@ -486,6 +488,24 @@ PyAPI_FUNC(wchar_t) Py_UNICODE_TOLOWER(wchar_t arg0);
 PyAPI_FUNC(double) Py_UNICODE_TONUMERIC(wchar_t arg0);
 PyAPI_FUNC(wchar_t) Py_UNICODE_TOTITLE(wchar_t arg0);
 PyAPI_FUNC(wchar_t) Py_UNICODE_TOUPPER(wchar_t arg0);
+PyAPI_FUNC(int) _PyArray_Check(PyObject *arg0);
+PyAPI_FUNC(int) _PyArray_CheckExact(PyObject *arg0);
+PyAPI_FUNC(void *) _PyArray_DATA(PyObject *arg0);
+PyAPI_FUNC(Py_ssize_t) _PyArray_DIM(PyObject *arg0, Py_ssize_t arg1);
+PyAPI_FUNC(PyObject *) _PyArray_DescrFromType(Py_ssize_t arg0);
+PyAPI_FUNC(int) _PyArray_FLAGS(PyObject *arg0);
+PyAPI_FUNC(PyObject *) _PyArray_FromAny(PyObject *arg0, PyObject *arg1, Py_ssize_t arg2, Py_ssize_t arg3, Py_ssize_t arg4, void *arg5);
+PyAPI_FUNC(PyObject *) _PyArray_FromObject(PyObject *arg0, Py_ssize_t arg1, Py_ssize_t arg2, Py_ssize_t arg3);
+PyAPI_FUNC(int) _PyArray_ITEMSIZE(PyObject *arg0);
+PyAPI_FUNC(Py_ssize_t) _PyArray_NBYTES(PyObject *arg0);
+PyAPI_FUNC(int) _PyArray_NDIM(PyObject *arg0);
+PyAPI_FUNC(PyObject *) _PyArray_New(void *arg0, Py_ssize_t arg1, Signed *arg2, Py_ssize_t arg3, Signed *arg4, void *arg5, Py_ssize_t arg6, Py_ssize_t arg7, PyObject *arg8);
+PyAPI_FUNC(Py_ssize_t) _PyArray_SIZE(PyObject *arg0);
+PyAPI_FUNC(Py_ssize_t) _PyArray_STRIDE(PyObject *arg0, Py_ssize_t arg1);
+PyAPI_FUNC(PyObject *) _PyArray_SimpleNew(Py_ssize_t arg0, Signed *arg1, Py_ssize_t arg2);
+PyAPI_FUNC(PyObject *) _PyArray_SimpleNewFromData(Py_ssize_t arg0, Signed *arg1, Py_ssize_t arg2, void *arg3);
+PyAPI_FUNC(PyObject *) _PyArray_SimpleNewFromDataOwning(Py_ssize_t arg0, Signed *arg1, Py_ssize_t arg2, void *arg3);
+PyAPI_FUNC(int) _PyArray_TYPE(PyObject *arg0);
 PyAPI_FUNC(void) _PyComplex_AsCComplex(PyObject *arg0, Py_complex *arg1);
 PyAPI_FUNC(PyObject *) _PyComplex_FromCComplex(Py_complex *arg0);
 PyAPI_FUNC(PyDateTime_CAPI *) _PyDateTime_Import(void);
